.. _api_constants:

.. py:module:: pyvisa.constants

Constants module
----------------

Provides user-friendly naming to values used in different functions.


.. autoclass:: AccessModes
    :members:
    :undoc-members:

.. autoclass:: StopBits
    :members:
    :undoc-members:

.. autoclass:: Parity
    :members:
    :undoc-members:

.. autoclass:: SerialTermination
    :members:
    :undoc-members:

.. autoclass:: InterfaceType
    :members:
    :undoc-members:

.. autoclass:: AddressState
    :members:
    :undoc-members:

.. autoclass:: IOProtocol
    :members:
    :undoc-members:

.. autoclass:: LineState
    :members:
    :undoc-members:

.. autoclass:: StatusCode
    :members:
    :undoc-members:
